@@ -1,7 +1,7 @@
 //! Provides SIMD-friendly allocator from SDL2.
 
-#![feature(allocator_api)]
 #![cfg(feature = "simd_allocator")]
+#![doc(cfg(feature = "simd_allocator"))]
 
 use std::{
     alloc::{AllocError, Allocator, Layout},
@@ -15,11 +15,15 @@ pub struct SimdAllocator;
 
 unsafe impl Allocator for SimdAllocator {
     fn allocate(&self, layout: Layout) -> Result<NonNull<[u8]>, AllocError> {
-        let ptr = unsafe { bind::SDL_SIMDAlloc(layout.size()) };
-        NonNull::new(ptr.cast()).unwrap_or(AllocError)
+        let ptr = unsafe { bind::SDL_SIMDAlloc(layout.size() as _) };
+        if ptr.is_null() {
+            return Err(AllocError);
+        }
+        let slice = unsafe { std::slice::from_raw_parts_mut(ptr.cast(), layout.size()) };
+        NonNull::new(slice).ok_or(AllocError)
     }
 
     unsafe fn deallocate(&self, ptr: NonNull<u8>, _layout: Layout) {
-        bind::SDL_SIMDFree(ptr.as_ptr());
+        bind::SDL_SIMDFree(ptr.as_ptr().cast());
     }
 }
